/* WinNTMouseWheel.h created by mercer on Mon 06-Dec-1999 */

#import <AppKit/NSEvent.h>
#import <AppKit/NSResponder.h>

@interface RCWinMouseWheel : NSObject

@end

/*"
 * The subtypes for recognized mouse wheel events, corresponding to the Windows
 * events WM_MOUSEWHEEL, WM_VSCROLL, and WM_HSCROLL. The event's type will
 * always be NSApplicationDefined.
"*/
#define MouseWheelSubtype        4242
#define VerticalScrollSubtype    4243
#define HorizontalScrollSubtype  4244

/*"
 * The increment to the delta values for each mouse wheel "notch". For now, the
 * mouse wheel deltas will most likely be an even multiple of this number. The
 * Windows documentation suggests that finer-grained values may be used in the
 * future.
"*/
#define MouseWheelNotchLevel 100

/*" The granularity to scroll for scroll events.  "*/
typedef enum {
    ScrollLines,  // -data2 is number of lines to scroll
    ScrollPages,  // -data2 is number of pages to scroll
    ScrollMax     // -data2 is which extreme to scroll to
} ScrollType;

@interface NSResponder (RCMouseWheelEventHandling)

// The methods that various NSResponder classes (NSViews, really) can implement
// if they want to handle mouse wheel events. Returns YES if the event was
// handled, NO if it should be forwarded on to the next responder. The default
// implementations return NO.

- (BOOL)mouseWheel:(NSEvent *)event;
- (BOOL)verticalScroll:(NSEvent *)event;
- (BOOL)horizontalScroll:(NSEvent *)event;

@end

@interface NSEvent (RCMouseWheel)

// Returns the delta for this mouse wheel event; the distance the mouse wheel
// traveled. It is most likely an even multiple of MouseWheelNotchLevel, which
// each level representing a turn of one "notch" on the mouse wheel. A positive
// value means the wheel was rotated forward (away from the user, or up), and a
// negative value means it was rotated backwards (towards the user, or down).
// The return value is only valid for a mouse wheel event (type NSAppKitDefined,
// subtype MouseWheelSubtype).
- (int)mouseWheelDelta;

// Returns the type (line, page, or max) for scroll events.
- (ScrollType)scrollType;
// returns the increment (# of lines/pages or which max direction) for scroll events.
- (int)scrollIncrement;

@end
